===================================================
Proyectos que han servido o servirán de inspiración
===================================================


* canaima-desarrollador
* canaima-semilla
* apt-portal
* askbot-devel
* clon-de-twitter-django-3.0
* debfactory
* django-achievements
* django-activity-stream
* django-filer
* django-photologue
* django-wiki
* django-postman
* profiles
* transifex
* django-inotifier
* gnotty
* django-projector
* django-static
* django-brainstorm
* django-ideas
* ribbit

	* http://net.tutsplus.com/tutorials/python-tutorials/building-ribbit-with-django/

* etherpad
* django-mailman
* Revisar vcs_support en readthedocs

	* https://github.com/rtfd/readthedocs.org/tree/master/readthedocs/vcs_support

* Revisar anyvc

	* https://bitbucket.org/RonnyPfannschmidt/anyvc

* Revisar ohcount

	* https://github.com/blackducksw/ohcount

* Revisar pitweb para extenderlo a los otros vcs

	* http://gitview.danfis.cz/pitweb.git?a=tree;id=HEAD;

* Revisar adhocracy

	* https://github.com/liqd/adhocracy

* Revisar Launchpad

	* https://dev.launchpad.net/
	* https://dev.launchpad.net/Getting
	* https://dev.launchpad.net/Running

* Revisar Rhodecode

	* http://pythonhosted.org/RhodeCode/

* Revisar Allura

	* http://sourceforge.net/p/allura/git/ci/master/tree/Allura/
	* http://allura.sourceforge.net/platform.html

* Revisar Klaus

	* https://github.com/jonashaag/klaus

* Revisar ReadTheDocs

	* https://github.com/rtfd/readthedocs.org

* Revisar Crate.io

	* https://github.com/crateio/crate.io
	* https://github.com/crateio/crate.web

* Revisar cache en django

	* https://docs.djangoproject.com/en/dev/topics/cache/
	* http://www.jeffknupp.com/blog/2012/02/24/django-memcached-optimizing-django-through-caching/

* Django+Ember.js+handlebars

	* http://www.rkblog.rk.edu.pl/w/p/creating-modern-web-applications-django-and-emberjs-javascript-framework/
	* http://discuss.emberjs.com/t/setting-up-a-django-api-to-use-with-ember-js/163/5
	* http://www.lostiemposcambian.com/blog/javascript/intro-framework-ember/
	* http://emberjs.com/guides/application/
	* http://handlebarsjs.com/

* Django+Node.js

	* http://stackoverflow.com/questions/8277299/using-node-js-with-django-and-backbone-js
	* http://maxburstein.com/blog/realtime-django-using-nodejs-and-socketio/

* Django Apps

	* http://www.rkblog.rk.edu.pl/w/p/django/
	* http://swizec.com/blog/django-protip-1-a-better-app-structure/swizec/1386

* Django+Redis

	* https://django-redis.readthedocs.org/en/latest/#django-redis

* coverage.py

	* http://ratnadeepdebnath.wordpress.com/2011/09/22/a-brief-introduction-to-coverage-py/

* Javascript charts

	* http://mbostock.github.com/d3/
	* http://code.shutterstock.com/rickshaw/

* Bootstrap

	* http://twitter.github.io/bootstrap/index.html

* Tastypie

	* http://django-tastypie.readthedocs.org/en/latest/tutorial.html#creating-resources

* Buildbot

	* http://i3wm.org/docs/buildbot.html
	* https://github.com/jollyroger/metabbotcfg/tree/434bea74cfbd37095ad21fe0c65af95bf8dce704
	* http://jacobian.org/writing/buildbot/configuration-and-architecture/
	* http://anonscm.debian.org/gitweb/?p=openstack/openstack-auto-builder.git;a=blob;f=build-openstack-pkg

* Fabric

	* http://docs.fabfile.org/en/1.6/index.html
	* http://agiletesting.blogspot.com/2009/11/automated-deployments-with-puppet-and.html

* Python distribute

	* http://guide.python-distribute.org/

* Testing & Django

	* http://toastdriven.com/blog/2011/apr/17/guide-to-testing-in-django-2/
	* http://toastdriven.com/blog/2011/apr/10/guide-to-testing-in-django/

* ACE Bootstrap: http://easy-themes.tk/themes/preview/ace/form-elements.html
* Drone.io: https://drone.io/
* Django+tastypie+ember

	* https://github.com/escalant3/ember-data-tastypie-adapter
	* https://github.com/toranb/complex-ember-data-example
	* https://github.com/toranb/ember-data-django-rest-adapter
	* http://www.rkblog.rk.edu.pl/w/p/creating-modern-web-applications-django-and-emberjs-javascript-framework/
	* http://discuss.emberjs.com/t/setting-up-a-django-api-to-use-with-ember-js/163
	* https://github.com/escalant3/django-ember-example/
	* http://tastypieapi.org/
	* http://django-tastypie.readthedocs.org/en/latest/tutorial.html

* Django+RSS

	* http://www.jjude.com/adding-rss-feeds-to-django-applications/
	* http://django.es/blog/crear-feeds-con-django/
